@@ -12,15 +12,17 @@ from MHDataLearn.modelselector.model_selector import split_data,\
                                             reveal_best_classification_model,\
                                             visualize_model_performance
 
-def train_default_models(df, imd=False):
+def train_default_models(df, imd_include=False):
     #Define X, Y for models
     Y = df['EmergencyReadmit']
     feature_list = ['age_admit', 'Gender', 'MaritalStatus', 'EmployStatus', 
                 'SettledAccommodationInd', 'MHCareClusterSuperClass', 
-                'HospitalBedTypeMH'
-    if imd:
+                'HospitalBedTypeMH']
+    if imd_include:
         feature_list.append('imd_dec')
-    X = df[feature_list]
+        X = df[feature_list]
+    else:
+        X = df[feature_list]
     #Scale features
     st_scaler = StandardScaler()
     X = pd.DataFrame(st_scaler.fit_transform(X))
